import 'package:flutter/material.dart';

/// min screen size 640x360
/// max screen size 2560x1800

double _sizeFrac(double min, double max, double val) => (val-min)/(max-min);


double _scaleFont({
    double minFontSize=12,
    double maxFontSize=30,
    required double height,
    required double width}
    ) {
  double hFrac = _sizeFrac(640, 2560, height);
  double wFrac = _sizeFrac(360, 1800, width);
  double minFrac = hFrac < wFrac ? hFrac : wFrac;
  return minFontSize+(minFrac*(maxFontSize-minFontSize));
}


class ScalingText extends StatelessWidget {
  final TextStyle _style;
  final double _fontSize;
  final String _text;


  ScalingText(
      BuildContext context,
      Key key,
      {
        required String text,
        TextStyle style = const TextStyle(),
        double minFontSize = 12,
        double maxFontSize = 30,
      }) :
      _text = text,
      _style = style,
      _fontSize = _scaleFont(
          minFontSize: minFontSize,
          maxFontSize: maxFontSize,
          height: MediaQuery.of(context).size.height,
          width: MediaQuery.of(context).size.width
      ),
      super(key: key);


  @override
  Widget build(BuildContext context) {
    return Text(this._text,
      style: this._style.copyWith(fontSize: this._fontSize),);
  }
}